pub struct ConditionStack { /* private fields */ }
| A data type to abstract out the condition | stack during script execution. | | Conceptually it acts like a vector of | booleans, one for each level of nested | | IF/THEN/ELSE, indicating whether | we’re in the active or inactive branch | of each. | | The elements on the stack cannot be observed | individually; we only need to expose | whether the stack is empty and whether | or not any false values are present at | all. To implement OP_ELSE, a toggle_top | modifier is added, which flips the last | value without returning it. | | This uses an optimized implementation | that does not materialize the actual | stack. Instead, it just stores the size | of the would-be stack, and the position | of the first false value in it. |

Implementations