pub struct TaprootBuilder { /* private fields */ }
| Utility class to construct Taproot | outputs from internal key and script | tree. |

Implementations

| Return true if so far all input was valid. |

| Return whether there were either no | leaves, or the leaves form a Huffman | tree. |

| Combine information about a parent | Merkle tree node from its child nodes. |

| Insert information about a node at a | certain depth, and propagate information | up. |

| Check if a list of depths is legal (will | lead to IsComplete()). |

| Add a new script at a certain depth in | the tree. Add() operations must be called | in depth-first traversal order of binary | tree. If track is true, it will be included | in the GetSpendData() output. |

| Like Add(), but for a Merkle node with | a given hash to the tree. |

| Finalize the construction. Can only | be called when IsComplete() is true. | internal_key.IsFullyValid() must | be true. |

| Compute scriptPubKey (after Finalize()). |

| Compute spending data (after Finalize()). |